@@ -99,7 +99,7 @@ setClass("H2OObject",
 setMethod("initialize", "H2OObject", function(.Object, ...) {
   .Object <- callNextMethod()
   .Object@finalizers <- .Object@finalizers[!duplicated(unlist(lapply(.Object@finalizers,
-                                                                     function(x) capture.output(print(x)))))]
+                                                                     function(x) utils::capture.output(print(x)))))]
   .Object
 })
 
@@ -688,7 +688,7 @@ str.H2OFrame <- function(object, cols=FALSE, ...) {
     cat("\nH2OFrame '", object@frame_id, "':\t", nr, " obs. of  ", nc, " variable(s)", "\n", sep = "")
     l <- list()
     for( i in 1:nc ) {
-      cat("$ ", cc[i], rep(' ', width - max(na.omit(c(0,nchar(cc[i]))))), ": ", sep="")
+      cat("$ ", cc[i], rep(' ', width - max(stats::na.omit(c(0,nchar(cc[i]))))), ": ", sep="")
       first.10.rows <- df[,i]
       if( isfactor[i] ) {
         nl <- num.levels[i]
