@@ -8,13 +8,13 @@ remoteH2O = h2o.init(ip = myIP, port = as.numeric(myPort), startH2O = FALSE)
 
 prostate.hex = h2o.uploadFile(remoteH2O, system.file("extdata", "prostate.csv", package="h2o"), "prostate.hex")
 summary(prostate.hex)
-prostate.gbm = h2o.gbm(x = setdiff(colnames(prostate.hex), "CAPSULE"), y = "CAPSULE", data = prostate.hex, n.trees = 10, interaction.depth = 5, shrinkage = 0.1)
+prostate.gbm = h2o.gbm(x = setdiff(colnames(prostate.hex), "CAPSULE"), y = "CAPSULE", training_frame = prostate.hex, ntrees = 10, max_depth = 5, learn_rate = 0.1)
 print(prostate.gbm)
-prostate.gbm2 = h2o.gbm(x = c("AGE", "RACE", "PSA", "VOL", "GLEASON"), y = "CAPSULE", data = prostate.hex, n.trees = 10, interaction.depth = 8, n.minobsinnode = 10, shrinkage = 0.2)
+prostate.gbm2 = h2o.gbm(x = c("AGE", "RACE", "PSA", "VOL", "GLEASON"), y = "CAPSULE", training_frame = prostate.hex, ntrees = 10, max_depth = 8, min_rows = 10, learn_rate = 0.2)
 print(prostate.gbm2)
 
 # This is a demo of H2O's GBM use of default parameters on iris dataset (three classes)
 iris.hex = h2o.uploadFile(remoteH2O, system.file("extdata", "iris.csv", package="h2o"), "iris.hex")
 summary(iris.hex)
-iris.gbm = h2o.gbm(x = 1:4, y = 5, data = iris.hex)
+iris.gbm = h2o.gbm(x = 1:4, y = 5, training_frame = iris.hex)
 print(iris.gbm)
